# WhatsOpt command line interface

[![Tests](https://github.com/OneraHub/WhatsOpt-CLI/workflows/Tests/badge.svg)](https://github.com/OneraHub/WhatsOpt-CLI/actions?query=workflow%3ATests)
[![Codacy Badge](https://app.codacy.com/project/badge/Grade/626b1d66073749cf8a7c8d40b6e63c7d)](https://app.codacy.com/gh/whatsopt/WhatsOpt-CLI/dashboard?utm_source=gh&utm_medium=referral&utm_content=&utm_campaign=Badge_grade)
[![Ruff](https://img.shields.io/endpoint?url=https://raw.githubusercontent.com/charliermarsh/ruff/main/assets/badge/v0.json)](https://github.com/charliermarsh/ruff)

Command line interface to interact with WhatsOpt web application. See [WhatsOpt documentation](https://github.com/OneraHub/WhatsOpt-Doc).

## Citation

>Rémi  Lafage,  Sébastien  Defoort,  and  Thierry  Lefèbvre. Whatsopt: a web application for multidisciplinary design analysis and optimization. In 20th AIAA/ISSMO Multidisciplinary Analysis and Optimization Conference, Dallas, United States, 2019

DOI: [10.2514/6.2019-2990](https://doi.org/10.2514/6.2019-2990)

## Installation

```bash
pip install wop
```

## Usage

```bash
wop --help
```

```bash
wop <COMMAND> --help
```

## License

   Copyright 2020-2024 Rémi Lafage

   Licensed under the Apache License, Version 2.0 (the "License");
   you may not use this file except in compliance with the License.
   You may obtain a copy of the License at

   <http://www.apache.org/licenses/LICENSE-2.0>

   Unless required by applicable law or agreed to in writing, software
   distributed under the License is distributed on an "AS IS" BASIS,
   WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
   See the License for the specific language governing permissions and
   limitations under the License.
